@@ -1,5 +1,5 @@
 /* KDE GTK Configuration Module
- * 
+ *
  * Copyright 2011 José Antonio Sanchez Reynaga <joanzare@gmail.com>
  * Copyright 2011 Aleix Pol Gonzalez <aleixpol@blue-systems.com>
  *
@@ -10,13 +10,13 @@
  * later version accepted by the membership of KDE e.V. (or its
  * successor approved by the membership of KDE e.V.), which shall
  * act as a proxy defined in Section 6 of version 3 of the license.
- * 
+ *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
- * 
- * You should have received a copy of the GNU Lesser General Public 
+ *
+ * You should have received a copy of the GNU Lesser General Public
  * License along with this library.  If not, see <http://www.gnu.org/licenses/>.
  */
 
@@ -28,6 +28,11 @@
 #include <KSharedConfig>
 #include <KConfigGroup>
 
+#undef signals
+#include <gio/gio.h>
+#include <gtk/gtk.h>
+#define signals Q_SIGNALS
+
 QStringList AppearanceGTK3::installedThemes() const
 {
     QFileInfoList availableThemes;
@@ -120,7 +125,7 @@ QString AppearanceGTK3::defaultConfigFile() const
     QString root = QStandardPaths::writableLocation(QStandardPaths::GenericConfigLocation);
     if(root.isEmpty())
         root = QFileInfo(QDir::home(), ".config").absoluteFilePath();
-    
+
     return root + '/' + configFileName();
 }
 
@@ -154,6 +159,33 @@ bool AppearanceGTK3::loadSettings()
 
 bool AppearanceGTK3::saveSettings() const
 {
+    // FIXME kdebz#387417
+    // We should maybe use GSettings everywhere in future, but at this moment we
+    // need this to have this configuration available in sandboxed applications which
+    // is only possible through dconf
+    gtk_init(nullptr, nullptr);
+
+    g_autoptr(GSettings) gsettings = g_settings_new("org.gnome.desktop.interface");
+    g_settings_set_string(gsettings, "gtk-theme", m_settings["theme"].toUtf8().constData());
+    g_settings_set_string(gsettings, "icon-theme", m_settings["icon"].toUtf8().constData());
+    g_settings_set_string(gsettings, "cursor-theme", m_settings["cursor"].toUtf8().constData());
+    g_settings_set_string(gsettings, "font-name", m_settings["font"].toUtf8().constData());
+
+    QString toolbarStyle;
+    if (m_settings["toolbar_style"] == QStringLiteral("GTK_TOOLBAR_ICONS")) {
+        toolbarStyle = QStringLiteral("icons");
+    } else if (m_settings["toolbar_style"] == QStringLiteral("GTK_TOOLBAR_TEXT")) {
+        toolbarStyle = QStringLiteral("text");
+    } else if (m_settings["toolbar_style"] == QStringLiteral("GTK_TOOLBAR_BOTH")) {
+        toolbarStyle = QStringLiteral("both");
+    } else if (m_settings["toolbar_style"] == QStringLiteral("GTK_TOOLBAR_BOTH_HORIZ")) {
+        toolbarStyle = QStringLiteral("both-horiz");
+    }
+
+    g_settings_set_string(gsettings, "toolbar-style", toolbarStyle.toUtf8().constData());
+
+    g_object_set(gtk_settings_get_default(), "gtk-application-prefer-dark-theme", getApplicationPreferDarkTheme(), nullptr);
+
     auto cfg = KSharedConfig::openConfig(configFileName(), KConfig::NoGlobals);
     return saveSettings(cfg);
 }
